@@ -9,7 +9,7 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 use Term::ANSIColor qw();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %SPEC;
 
@@ -32,36 +32,47 @@ _
             req => 1,
         },
     },
-    tags => [qw/text ansi/],
+    tags => [qw/text ansi itemfunc/],
     "x.dux.default_format" => "text-simple",
 };
 sub color {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
 
-    my $color = $args{color};
-    $color = Term::ANSIColor::color($color) unless $color =~ /\A\e/;
-
     while (my ($index, $item) = each @$in) {
-        {
-            last if !defined($item) || ref($item);
-            $item = $color . $item . "\e[0m";
-        }
-        push @$out, $item;
+        push @$out, _color_item($item, \%args);
     }
 
     [200, "OK"];
 }
 
+sub _color_begin {
+    my $args = shift;
+
+    # abuse args to store state
+    my $color = $args->{color};
+    $color = Term::ANSIColor::color($color) unless $color =~ /\A\e/;
+    $args->{_color} = $color;
+}
+
+sub _color_item {
+    my ($item, $args) = @_;
+
+    {
+        last if !defined($item) || ref($item);
+        $item = $args->{_color} . $item . "\e[0m";
+    }
+    return $item;
+}
+
 1;
 # ABSTRACT: Colorize text with ANSI color codes
 
-
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -69,38 +80,23 @@ Data::Unixish::ansi::color - Colorize text with ANSI color codes
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
 In Perl:
 
- use Data::Unixish::List qw(dux);
- $colorized = dux(['ansi::color' => {color=>"red"}], "red"); # "\e[31mred\e[0m"
+ use Data::Unixish qw(lduxl);
+ $colorized = lduxl(['ansi::color' => {color=>"red"}], "red"); # "\e[31mred\e[0m"
 
 In command line:
 
  % echo -e "HELLO" | dux ansi::color --color red; # text will appear in red
  HELLO
 
-=head1 AUTHOR
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Steven Haryanto.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 color(%args) -> [status, msg, result, meta]
 
 Colorize text with ANSI color codes.
@@ -130,7 +126,40 @@ Output stream (e.g. array or filehandle).
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish-ansi>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish-ansi>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish-ansi>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Steven Haryanto.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
